@@ -1,5 +1,5 @@
 /* info.h -- Header file which includes all of the other headers.
-   $Id: info.h,v 1.7 2007/07/01 21:20:30 karl Exp $
+   $Id: info.h,v 1.9 2008/05/10 14:39:05 gray Exp $
 
    Copyright (C) 1993, 1997, 1998, 1999, 2001, 2002, 2003, 2004, 2007
    Free Software Foundation, Inc.
@@ -43,6 +43,10 @@ typedef char *CFunction ();
 #include "footnotes.h"
 #include "gc.h"
 
+#include "string.h"
+#include "mbiter.h"
+#include "mbchar.h"
+
 #define info_toupper(x) (islower (x) ? toupper (x) : x)
 #define info_tolower(x) (isupper (x) ? tolower (x) : x)
 
@@ -125,7 +129,7 @@ extern int raw_escapes_p;
 /* Print FORMAT with ARG1 and ARG2.  If the window system was initialized,
    then the message is printed in the echo area.  Otherwise, a message is
    output to stderr. */
-extern void info_error (char *format, void *arg1, void *arg2);
+extern void info_error (const char *format, void *arg1, void *arg2);
 
 extern void add_file_directory_to_path (char *filename);
 
@@ -154,6 +158,6 @@ extern void set_variable_to_value (char *name, char *value);
 #endif /* INFOKEY */
 
 /* Found in m-x.c.  */
-extern char *read_function_name (char *prompt, WINDOW *window);
+extern char *read_function_name (const char *prompt, WINDOW *window);
 
 #endif /* !INFO_H */
