@@ -1,12 +1,13 @@
 /* html.h -- declarations for html-related utilities.
-   $Id: html.h,v 1.6.2.1 2007/06/27 17:11:01 karl Exp $
+   $Id: html.h,v 1.11 2008/05/19 18:26:48 karl Exp $
 
-   Copyright (C) 1999, 2000, 2002, 2004, 2007 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2000, 2002, 2004, 2007, 2008
+   Free Software Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or modify
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 3, or (at your option)
-   any later version.
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,8 +15,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 #ifndef HTML_H
 #define HTML_H
@@ -28,12 +28,13 @@ typedef struct hstack
   char *attribs;
 } HSTACK;
 
-/* Nonzero if we have output the <head>.  */
-extern int html_output_head_p;
-
 /* Nonzero if we have output a title, from @titlefont or @settitle.  */
 extern int html_title_written;
 
+/* Filename to which to write list of index entries, and stream for them */
+extern char *internal_links_filename;
+extern FILE *internal_links_stream;
+
 /* Perform the <head> output.  */
 extern void html_output_head (void);
 
@@ -47,6 +48,7 @@ extern void insert_html_tag (int start_or_end, char *tag);
 extern void add_link (char *nodename, char *attributes);
 
 /* Escape URL-special characters.  */
+extern char *escaped_anchor_name (const char *name);
 extern void add_escaped_anchor_name (char *name, int old);
 
 /* See html.c.  */
