@@ -1,12 +1,12 @@
 /* sectioning.h -- all related stuff @chapter, @section... @contents
-   $Id: sectioning.h,v 1.2 2004/02/13 22:01:39 dirt Exp $
+   $Id: sectioning.h,v 1.8 2007/07/01 21:20:33 karl Exp $
 
-   Copyright (C) 1999, 2003 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2003, 2007 Free Software Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or modify
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,8 +14,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
    Written by Karl Heinz Marbaise <kama@hippo.fido.de>.  */
 
@@ -58,7 +57,7 @@ extern void cm_raisesections (void),
 
 extern void
   sectioning_underscore (char *cmd),
-  insert_and_underscore (int level, int with_char, char *cmd);
+  insert_and_underscore (int level, char *cmd);
 
 /* needed in node.c */
 extern int set_top_section_level (int level);
