@@ -1,7 +1,7 @@
 /* xml.c -- xml output, both TexinfoML and Docbook.
-   $Id: xml.c,v 1.72 2007/07/01 21:20:33 karl Exp $
+   $Id: xml.c,v 1.75 2008/01/31 18:33:27 karl Exp $
 
-   Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007
+   Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008
    Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
@@ -165,6 +165,9 @@ element texinfoml_element_list [] = {
 
   { "dmn",                 0, 1, 0 },
 
+  { "clicksequence",       0, 1, 0 },
+  { "click",               0, 1, 0 },
+
   { "xref",                0, 1, 0 },
   { "xrefnodename",        0, 1, 0 },
   { "xrefinfoname",        0, 1, 0 },
@@ -379,6 +382,9 @@ element docbook_element_list [] = {
 
   { "",                    0, 1, 0 }, /* DIMENSION */
 
+  { "",                    0, 1, 0 }, /* CLICKSEQUENCE */
+  { "",                    0, 1, 0 }, /* CLICK */
+
   { "xref",                0, 1, 0 }, /* XREF */
   { "link",                0, 1, 0 }, /* XREFNODENAME */
   { "",                    0, 1, 0 }, /* XREFINFONAME */
@@ -605,7 +611,7 @@ xml_element (char *name)
   int i;
   for (i = 0; i<=PARA; i++)
     {
-      if (strcasecmp (name, texinfoml_element_list[i].name) == 0)
+      if (mbscasecmp (name, texinfoml_element_list[i].name) == 0)
         return i;
     }
   printf ("Error xml_element\n");
@@ -613,7 +619,7 @@ xml_element (char *name)
 }
 
 void
-xml_begin_document (char *output_filename)
+xml_begin_document (const char *output_basename)
 {
   if (book_started)
     return;
@@ -658,23 +664,29 @@ xml_begin_document (char *output_filename)
 
   if (strcmp (xml_element_list[PARA].name, "para"))
     {
-      printf ("internal error: xml_element_list table inconsistent");
+      warning ("internal error: xml_element_list table inconsistent");
       xexit (-1);
     }
 
   if (language_code != last_language_code)
     {
       if (docbook)
-	/* The toplevel <book> element needs an id attribute if you want to use
-	   the chunk.xml feature of the DocBook-XSL stylesheets. */
-        xml_insert_element_with_attribute (TEXINFO, START, "id=\"book-root\" lang=\"%s\"", language_table[language_code].abbrev);
+	/* The toplevel <book> element needs an id attribute if you want
+           to use the chunk.xml feature of the Docbook-XSL stylesheets.
+           Might as well use the output filename?  */
+        xml_insert_element_with_attribute (TEXINFO, START,
+                                           "id=\"%s\" lang=\"%s\"",
+                                         output_basename,
+                                         language_table[language_code].abbrev);
       else
-	xml_insert_element_with_attribute (TEXINFO, START, "xml:lang=\"%s\"", language_table[language_code].abbrev);
+	xml_insert_element_with_attribute (TEXINFO, START,
+                                           "xml:lang=\"%s\"",
+                                         language_table[language_code].abbrev);
     }
   if (!docbook)
     {
       xml_insert_element (SETFILENAME, START);
-      insert_string (output_filename);
+      insert_string (output_basename);
       xml_insert_element (SETFILENAME, END);
     }
 }
@@ -694,10 +706,9 @@ static void
 xml_push_current_element (int elt)
 {
   element_stack[element_stack_index++] = elt;
-  if (element_stack_index > 200)
-    printf ("*** stack overflow (%d - %s) ***\n",
-            element_stack_index,
-            xml_element_list[elt].name);
+  if (element_stack_index > 200)  /* fixxme, no hard limits */
+    warning ("internal error: xml stack overflow (%d - %s)",
+             element_stack_index, xml_element_list[elt].name);
 }
 
 static void
@@ -706,7 +717,8 @@ xml_pop_current_element (void)
   element_stack_index--;
   if (element_stack_index < 0)
     {
-      printf ("*** stack underflow (index %d) ***\n", element_stack_index);
+      warning ("internal error: xml stack underflow (index %d)",
+               element_stack_index);
       element_stack_index = 0;
     }
 }
@@ -1044,15 +1056,18 @@ xml_insert_entity (char *entity_name)
 {
   int saved_escape_html = escape_html;
 
-  if (!book_started)
-    return;
-  if (docbook && !only_macro_expansion && (in_menu || in_detailmenu))
-    return;
+  if (xml)
+    {
+    if (!book_started)
+      return;
+    if (docbook && !only_macro_expansion && (in_menu || in_detailmenu))
+      return;
 
-  if (!xml_in_para && !xml_no_para && !only_macro_expansion
-      && xml_element_list[xml_current_element ()].contains_para
-      && !in_fixed_width_font)
-    xml_start_para ();
+    if (!xml_in_para && !xml_no_para && !only_macro_expansion
+        && xml_element_list[xml_current_element ()].contains_para
+        && !in_fixed_width_font)
+      xml_start_para ();
+  }
 
   escape_html = 0;
   add_char ('&');
@@ -1084,7 +1099,7 @@ xml_begin_node (void)
       xml_insert_element (BOOKINFO, END);
       xml_in_bookinfo = 0;
     }
-  if (xml_node_open && ! docbook)
+  if (xml_node_open && !docbook)
     {
       if (xml_node_level != -1)
         {
@@ -1361,15 +1376,15 @@ xml_insert_quotation (char *type, int arg)
       /* Let's assume it started.  */
       quotation_started = 1;
 
-      if (strcasecmp (type, "tip") == 0)
+      if (mbscasecmp (type, "tip") == 0)
         xml_insert_element (TIP, arg);
-      else if (strcasecmp (type, "note") == 0)
+      else if (mbscasecmp (type, "note") == 0)
         xml_insert_element (NOTE, arg);
-      else if (strcasecmp (type, "important") == 0)
+      else if (mbscasecmp (type, "important") == 0)
         xml_insert_element (IMPORTANT, arg);
-      else if (strcasecmp (type, "warning") == 0)
+      else if (mbscasecmp (type, "warning") == 0)
         xml_insert_element (WARNING, arg);
-      else if (strcasecmp (type, "caution") == 0)
+      else if (mbscasecmp (type, "caution") == 0)
         xml_insert_element (CAUTION, arg);
       else
         /* Didn't find a known quotation type :\ */
