@@ -1,7 +1,7 @@
 /* xml.h -- xml (including Docbook) output declarations.
-   $Id: xml.h,v 1.30 2007/07/01 21:20:33 karl Exp $
+   $Id: xml.h,v 1.32 2008/01/31 18:33:28 karl Exp $
 
-   Copyright (C) 2001, 2002, 2003, 2004, 2005, 2007
+   Copyright (C) 2001, 2002, 2003, 2004, 2005, 2007, 2008
    Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
@@ -79,6 +79,7 @@ enum xml_element
   ITEMIZE, ITEMFUNCTION, ITEM, ENUMERATE, TABLE, TABLEITEM, TABLETERM,
   INDEXTERM, 
   MATH, DIMENSION,
+  CLICKSEQUENCE, CLICK,
   XREF, XREFNODENAME, XREFINFONAME, XREFPRINTEDDESC, XREFINFOFILE,
     XREFPRINTEDNAME, 
   INFOREF, INFOREFNODENAME, INFOREFREFNAME, INFOREFINFONAME, 
@@ -114,7 +115,7 @@ extern void xml_add_char (int character),
   xml_synindex (char *from, char *to),
   xml_start_para (void),
   xml_end_para (void),
-  xml_begin_document (char *output_filename),
+  xml_begin_document (const char *output_basename),
   xml_end_document (void),
   xml_start_menu_entry (char *tem),
   xml_end_menu (void),
